#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandwich
version:              0.2.2.0
visibility:           public
id:                   sandwich-0.2.2.0-5GlHeEqmzsZAnOu1hGRiYD
key:                  sandwich-0.2.2.0-5GlHeEqmzsZAnOu1hGRiYD
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  54e751ea8abb7906ec34dc815b36b6dd
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH Test.Sandwich.Util.Process

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util
    Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.RunTimes
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types
    Test.Sandwich.Golden.Update Test.Sandwich.Internal.Formatters
    Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich

import-dirs:          /usr/lib/ghc-9.6.6/site-local/sandwich-0.2.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sandwich-0.2.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sandwich-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.2.2.0-5GlHeEqmzsZAnOu1hGRiYD
depends:
    aeson-2.2.2.0-CuqyF0GV84l91XsdnO7HOm
    ansi-terminal-1.1-2Z7fTrN8LMzABCDpsj0YeJ
    async-2.2.6-JvoT9znxQt2BsREADqk9DD base-4.18.2.1
    brick-2.5-LJ4AoJmxab45K4c8dxju5V bytestring-0.11.5.3
    colour-2.3.7-KkFw92GKKvW2X4RWChhdIQ containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 free-5.2-Dh7NpJ39NfO9sVJ19HaAmZ
    haskell-src-exts-1.23.1-BXSFl1DB4M5DehH2FCUimt
    lifted-async-0.11.0-6DUXpt1atIgFvubCHQqLpc
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT
    monad-control-1.0.3.1-JM0SjCnFOQ8L8tLyJmlb3R
    monad-logger-0.3.42-LmYAi2Ir8LAQoxnZycwOT mtl-2.3.1
    optparse-applicative-0.18.1.0-HIDucWLVsMnBph0dP0V3D6
    pretty-show-1.10-EXsS4VwIV5tJ56gbmVdfrR process-1.6.19.0
    retry-0.9.3.1-C6hdN5EM1bd71j2KT06hbJ
    safe-0.3.21-2iv11P1GTSG3w8ujmSn6bG
    safe-exceptions-0.1.7.4-AJi6AhcOU2XILudArjgfZI stm-2.5.1.0
    string-interpolate-0.3.4.0-Lk9dsOwPln74SPBxyrWU2E
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-AFCnEHOqJ7M38kM1caOtcP unix-2.8.4.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    vector-0.13.2.0-KHhvLzyWGFJKP6boEp8Bp2
    vty-6.2-GFrkwL9F48F6BMALSylksk
    vty-crossplatform-0.4.0.0-KNnEcIrzhzfFCpMHtiIpxZ

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

